from logger import Logger
from services.basicservice import BasicService
from servicestub import ServiceStub
from singleton import Singleton
from typing import Dict, Iterable, Any
import os


class SmartScales(BasicService, metaclass=Singleton):
    log: Logger
    cases: Dict[str, Iterable[Dict[str, Any]]]

    def __init__(self):
        super().__init__(os.path.dirname(os.path.abspath(__file__)))

    def registerRoutes(self, servicestub: ServiceStub):
        self.log.info('Регистрация сервиса smartscales')
        self._loadCases('smartscales.json')

        servicestub.route('/smartscales/predict', method='POST', callback=self.predict)
        servicestub.route('/smartscales/update_prediction', method='POST', callback=self.updatePrediction)
        servicestub.route('/smartscales/get_status', method='GET', callback=self.getStatus)

    def predict(self):
        self.log.info('Распознание товара')
        methodPath = '/predict'

        return self._createResponse(methodPath)

    def updatePrediction(self):
        self.log.info('Получение информации с весов')
        methodPath = '/update_prediction'

        return self._createResponse(methodPath)

    def getStatus(self):
        self.log.info('Получение статуса')
        methodPath = '/get_status'

        return self._createResponse(methodPath)


instance = SmartScales()
